[![Build Status](https://travis-ci.com/rlworkgroup/akro.svg?branch=master)](https://travis-ci.com/rlworkgroup/akro)
[![codecov](https://codecov.io/gh/rlworkgroup/akro/branch/master/graph/badge.svg)](https://codecov.io/gh/rlworkgroup/akro)
[![Docs](https://readthedocs.org/projects/akro/badge)](http://akro.readthedocs.org/en/latest/)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/rlworkgroup/akro/blob/master/LICENSE)
[![PyPI version](https://badge.fury.io/py/akro.svg)](https://badge.fury.io/py/akro)

# akro
Spaces types for reinforcement learning

## Installation
```shell
pip install akro
```
